@@ -375,10 +375,41 @@ setup_signals (sighandler_t handler)
 
 
 static void
-sdt_benchmark_thread(unsigned long i, double *fpointer)
+sdt_benchmark_thread(unsigned long i, double fp1, float fp2)
 {
   PROBE(stap, benchmark__thread__start);
-  *fpointer += 0.0;
+  fp1 += 0.0;
+  fp2 += 0.0;
+  double fp_local1 = 1.01;
+  float fp_local2 = 2.02;
+  double fp_local3 = 3.03;
+  double fp_local4 = 4.04;
+  double fp_local5 = 5.05;
+  double fp_local6 = 6.06;
+  double fp_local7 = 7.07;
+  double fp_local8 = 8.08;
+  double fp_local9 = 9.09;
+  double fp_local10 = 10.01;
+  double fp_local11 = 11.01;
+  double fp_local12 = 12.01;
+  double fp_local13 = 13.01;
+  double fp_local14 = 14.01;
+  double fp_local15 = 15.01;
+  fp_local1 += 0.0;
+  fp_local2 += 0.0;
+  fp_local3 += 0.0;
+  fp_local4 += 0.0;
+  fp_local5 += 0.0;
+  fp_local6 += 0.0;
+  fp_local7 += 0.0;
+  fp_local8 += 0.0;
+  fp_local9 += 0.0;
+  fp_local10 += 0.0;
+  fp_local11 += 0.0;
+  fp_local12 += 0.0;
+  fp_local13 += 0.0;
+  fp_local14 += 0.0;
+  fp_local15 += 0.0;
   while (i--)
     PROBE1(stap, benchmark, i);
   PROBE(stap, benchmark__thread__end);
@@ -405,8 +436,9 @@ run_sdt_benchmark(systemtap_session& s)
     {
       vector<thread> handles;
       double f = 2.71828;
+      float f2 = 1.41421;
       for (unsigned long i = 0; i < threads; ++i)
-        handles.push_back(thread(sdt_benchmark_thread, loops,&f));
+        handles.push_back(thread(sdt_benchmark_thread, loops, f, f2));
       for (unsigned long i = 0; i < threads; ++i)
         handles[i].join();
     }
